@@ -1,8 +1,8 @@
 /*
  *  Screentest - CRT/LCD monitor testing utility.
- *  http://screentest.sourceforge.net/
+ *  https://tobix.github.io/screentest/
  *  Copyright (C) 2001 Jan "Yenya" Kasprzak <kas@fi.muni.cz>
- *  Copyright (C) 2006-2007 Tobias Gruetzmacher <tobias@portfolio16.de>
+ *  Copyright (C) 2006-2017 Tobias Gruetzmacher <tobias-screentest@23.gs>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 
 #include "callbacks.h"
 #include "main.h"
@@ -42,13 +41,12 @@ int fg_count = COLOR_WHITE;
 static GtkWidget *mainwin = NULL;
 static struct test_ops *current_test = &basic_ops;
 
-void on_mainwin_realize(GtkWidget * widget, G_GNUC_UNUSED gpointer user_data)
+G_MODULE_EXPORT void
+on_mainwin_realize(GtkWidget * widget, G_GNUC_UNUSED gpointer user_data)
 {
 	gint i;
 
-#ifdef DEBUG
-	gdk_window_resize(widget->window, 800, 600);
-#else
+#ifndef DEBUG
 	gtk_window_fullscreen(GTK_WINDOW(widget));
 #endif
 
@@ -83,8 +81,8 @@ void on_mainwin_realize(GtkWidget * widget, G_GNUC_UNUSED gpointer user_data)
 
 	mainwin = widget;
 
-	gc = gdk_gc_new(mainwin->window);
-	backgc = gdk_gc_new(mainwin->window);
+	gc = gdk_gc_new(gtk_widget_get_window(mainwin));
+	backgc = gdk_gc_new(gtk_widget_get_window(mainwin));
 
 	if (current_test->init != NULL)
 		current_test->init(widget);
@@ -95,7 +93,7 @@ static void update_fg_color(void)
 	gdk_gc_set_rgb_fg_color(gc, fg_color);
 	gdk_gc_set_rgb_bg_color(backgc, fg_color);
 
-	gdk_window_invalidate_rect(mainwin->window, NULL, FALSE);
+	gdk_window_invalidate_rect(gtk_widget_get_window(mainwin), NULL, FALSE);
 }
 
 static void update_bg_color(void)
@@ -104,20 +102,20 @@ static void update_bg_color(void)
 	gdk_gc_set_rgb_bg_color(gc, bg_color);
 	gdk_gc_set_rgb_fg_color(backgc, bg_color);
 
-	gdk_window_invalidate_rect(mainwin->window, NULL, FALSE);
+	gdk_window_invalidate_rect(gtk_widget_get_window(mainwin), NULL, FALSE);
 }
 
-gboolean
+G_MODULE_EXPORT gboolean
 on_mainwin_button_press_event(GtkWidget *widget, GdkEventButton *event,
 		G_GNUC_UNUSED gpointer user_data)
 {
-	GtkWidget *popup;
+	GObject *popup;
 
 	switch (event->button) {
 	case 1:
 		if (current_test->cycle != NULL) {
 			current_test->cycle(widget);
-			gdk_window_invalidate_rect(mainwin->window, NULL, FALSE);
+			gdk_window_invalidate_rect(gtk_widget_get_window(mainwin), NULL, FALSE);
 		}
 		break;
 	case 2:
@@ -128,7 +126,7 @@ on_mainwin_button_press_event(GtkWidget *widget, GdkEventButton *event,
 		update_fg_color();
 		break;
 	case 3:
-		popup = glade_xml_get_widget(glade, "popup");
+		popup = gtk_builder_get_object(builder, "popup");
 		gtk_menu_popup(GTK_MENU(popup), NULL, NULL, NULL, NULL,
 			       event->button, event->time);
 		break;
@@ -140,7 +138,7 @@ on_mainwin_button_press_event(GtkWidget *widget, GdkEventButton *event,
  * FIXME: GTK_WINDOW_POPUP does not seem to be able to receive
  * KeyPress events. How to enable this?
  */
-gboolean
+G_MODULE_EXPORT gboolean
 on_mainwin_key_press_event(G_GNUC_UNUSED GtkWidget *widget,
 		G_GNUC_UNUSED GdkEventKey *event,
 		G_GNUC_UNUSED gpointer user_data)
@@ -149,29 +147,30 @@ on_mainwin_key_press_event(G_GNUC_UNUSED GtkWidget *widget,
 	return FALSE;
 }
 
-gboolean
+G_MODULE_EXPORT gboolean
 on_mainwin_expose_event(GtkWidget *widget, G_GNUC_UNUSED GdkEventExpose *event,
 		G_GNUC_UNUSED gpointer user_data)
 {
-	gdk_window_set_background(widget->window, bg_color);
-	gdk_window_clear(widget->window);
+	gdk_window_set_background(gtk_widget_get_window(widget), bg_color);
+	gdk_window_clear(gtk_widget_get_window(widget));
 
 	if (current_test && current_test->draw)
 		current_test->draw(widget);
 	return TRUE;
 }
 
-void on_mode_change(GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer user_data)
+G_MODULE_EXPORT void
+on_mode_change(GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer user_data)
 {
 	GtkCheckMenuItem *checkmenuitem = GTK_CHECK_MENU_ITEM(menuitem);
 
-	if (!checkmenuitem->active) {
+	if (!gtk_check_menu_item_get_active(checkmenuitem)) {
 		if (current_test->close != NULL) {
 			current_test->close(mainwin);
 			current_test = NULL;
 		}
 	} else {
-		const char *test_name = glade_get_widget_name(GTK_WIDGET(menuitem));
+		const char *test_name = gtk_buildable_get_name(GTK_BUILDABLE(menuitem));
 		g_assert(test_name != NULL);
 		GModule *exe = g_module_open(NULL, 0);
 		g_assert(exe != NULL);
@@ -188,22 +187,23 @@ void on_mode_change(GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer user_data)
 		}
 		free(test_struct);
 		g_module_close(exe);
-		if (current_test->init != NULL) {
+		if (current_test != NULL && current_test->init != NULL) {
 			current_test->init(mainwin);
 		}
 		on_mainwin_expose_event(mainwin, NULL, NULL);
 	}
 }
 
-void on_fg_color_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
+G_MODULE_EXPORT void
+on_fg_color_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
 		G_GNUC_UNUSED gpointer user_data)
 {
 	GtkColorSelection *colorsel;
-	GtkWidget *fg_color_selector;
+	GObject *fg_color_selector;
 
-	fg_color_selector = glade_xml_get_widget(glade, "fg_color_selector");
+	fg_color_selector = gtk_builder_get_object(builder, "fg_color_selector");
 
-	colorsel = GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(fg_color_selector)->colorsel);
+	colorsel = GTK_COLOR_SELECTION(gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG(fg_color_selector)));
 	gtk_color_selection_set_current_color(colorsel, fg_color);
 	switch (gtk_dialog_run(GTK_DIALOG(fg_color_selector))) {
 		case GTK_RESPONSE_OK:
@@ -217,18 +217,19 @@ void on_fg_color_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
 		default:
 			g_assert_not_reached();
 	}
-	gtk_widget_hide(fg_color_selector);
+	gtk_widget_hide(GTK_WIDGET(fg_color_selector));
 }
 
-void on_bg_color_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
+G_MODULE_EXPORT void
+on_bg_color_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
 		G_GNUC_UNUSED gpointer user_data)
 {
 	GtkColorSelection *colorsel;
-	GtkWidget *bg_color_selector;
+	GObject *bg_color_selector;
 
-	bg_color_selector = glade_xml_get_widget(glade, "bg_color_selector");
+	bg_color_selector = gtk_builder_get_object(builder, "bg_color_selector");
 
-	colorsel = GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(bg_color_selector)->colorsel);
+	colorsel = GTK_COLOR_SELECTION(gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG(bg_color_selector)));
 	gtk_color_selection_set_current_color(colorsel, bg_color);
 	switch (gtk_dialog_run(GTK_DIALOG(bg_color_selector))) {
 		case GTK_RESPONSE_OK:
@@ -242,6 +243,6 @@ void on_bg_color_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
 		default:
 			g_assert_not_reached();
 	}
-	gtk_widget_hide(bg_color_selector);
+	gtk_widget_hide(GTK_WIDGET(bg_color_selector));
 }
 
