@@ -1,8 +1,8 @@
 /*
  *  Screentest - CRT/LCD monitor testing utility.
- *  http://screentest.sourceforge.net/
+ *  https://tobix.github.io/screentest/
  *  Copyright (C) 2001 Jan "Yenya" Kasprzak <kas@fi.muni.cz>
- *  Copyright (C) 2006-2007 Tobias Gruetzmacher <tobias@portfolio16.de>
+ *  Copyright (C) 2006-2017 Tobias Gruetzmacher <tobias-screentest@23.gs>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -24,39 +24,41 @@
 
 #include <stdlib.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 
 #include "main.h"
 #include "gettext.h"
 #define _(String) gettext(String)
 
-GladeXML *glade;
+GtkBuilder *builder;
 
 int main(int argc, char *argv[])
 {
+	guint err;
+
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 
 	gtk_init(&argc, &argv);
 
-	glade = glade_xml_new(DATADIR "/screentest.glade", NULL, NULL);
-	if (glade == NULL)
-		glade = glade_xml_new("screentest.glade", NULL, NULL);
-	if (glade == NULL) {
+	builder = gtk_builder_new();
+	err = gtk_builder_add_from_file(builder, DATADIR "/screentest.ui", NULL);
+	if (err == 0)
+		err = gtk_builder_add_from_file(builder, "screentest.ui", NULL);
+	if (err == 0) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL,
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-			_("The GLADE interface definition file was not found.\n"
+			_("The interface definition file was not found.\n"
 			"Please make sure this program is installed correctly."));
 		gtk_window_set_title(GTK_WINDOW(dialog), PACKAGE_NAME);
 		gtk_dialog_run(GTK_DIALOG(dialog));
 		exit(1);
 	}
 
-	glade_xml_signal_autoconnect(glade);
+	gtk_builder_connect_signals(builder, NULL);
 
-	gtk_widget_show(glade_xml_get_widget(glade, "mainwin"));
+	gtk_widget_show_all(GTK_WIDGET(gtk_builder_get_object(builder, "mainwin")));
 	gtk_main();
 	return 0;
 }
