@@ -1,8 +1,8 @@
 /*
  *  Screentest - CRT/LCD monitor testing utility.
- *  http://screentest.sourceforge.net/
+ *  https://tobix.github.io/screentest/
  *  Copyright (C) 2001 Jan "Yenya" Kasprzak <kas@fi.muni.cz>
- *  Copyright (C) 2006-2007 Tobias Gruetzmacher <tobias@portfolio16.de>
+ *  Copyright (C) 2006-2017 Tobias Gruetzmacher <tobias-screentest@23.gs>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -21,8 +21,8 @@
 #ifndef _MAIN_H
 #define _MAIN_H 1
 
-#include <glade/glade.h>
+#include <gtk/gtk.h>
 
-extern GladeXML *glade;
+extern GtkBuilder *builder;
 
 #endif /* _MAIN_H */
